@@ -1,14 +1,14 @@
 from django.contrib import admin
-from .models import QuizQuestion, QuizAnswer
-from solid_backend.utility.forms import HasImgForm
+
+from .models import QuizAnswer, QuizQuestion
 
 
 class QuizAnswerInline(admin.TabularInline):
     model = QuizAnswer
+    extra = 1
 
 
 class QuizQuestionAdmin(admin.ModelAdmin):
-    form = HasImgForm
     list_display = ["id", "text"]
     inlines = [
         QuizAnswerInline,
